.. currentmodule:: axelrod.strategies
Index of strategies
===================

Basic strategies
----------------

.. autoclass:: Alternator
.. autoclass:: Cooperator
.. autoclass:: Defector
.. autoclass:: Random
.. autoclass:: TitForTat

Further (honest) Strategies
---------------------------

.. autoclass:: AlternatorHunter
.. autoclass:: Appeaser
.. autoclass:: AntiTitForTat
.. autoclass:: ArrogantQLearner
.. autoclass:: AverageCopier
.. autoclass:: Bully
.. autoclass:: CautiousQLearner
.. autoclass:: CooperatorHunter
.. autoclass:: Davis
.. autoclass:: DefectorHunter
.. autoclass:: e
.. autoclass:: Feld
.. autoclass:: FoolMeOnce
.. autoclass:: ForgetfulFoolMeOnce
.. autoclass:: ForgetfulGrudger
.. autoclass:: Forgiver
.. autoclass:: ForgivingTitForTat
.. autoclass:: GTFT
.. autoclass:: GoByMajority
.. autoclass:: GoByMajority10
.. autoclass:: GoByMajority20
.. autoclass:: GoByMajority40
.. autoclass:: GoByMajority5
.. autoclass:: Golden
.. autoclass:: Grofman
.. autoclass:: Grudger
.. autoclass:: Grumpy
.. autoclass:: HesitantQLearner
.. autoclass:: Inverse
.. autoclass:: InversePunisher
.. autoclass:: Joss
.. autoclass:: LimitedRetaliate
.. autoclass:: LimitedRetaliate2
.. autoclass:: LimitedRetaliate3
.. autoclass:: MathConstantHunter
.. autoclass:: MetaHunter
.. autoclass:: MetaMajority
.. autoclass:: MetaMinority
.. autoclass:: MetaWinner
.. autoclass:: NiceAverageCopier
.. autoclass:: OnceBitten
.. autoclass:: OppositeGrudger
.. autoclass:: Pi
.. autoclass:: Punisher
.. autoclass:: RandomHunter
.. autoclass:: Retaliate
.. autoclass:: Retaliate2
.. autoclass:: Retaliate3
.. autoclass:: RiskyQLearner
.. autoclass:: Shubik
.. autoclass:: SneakyTitForTat
.. autoclass:: StochasticWSLS
.. autoclass:: SuspiciousTitForTat
.. autoclass:: TitFor2Tats
.. autoclass:: TrickyCooperator
.. autoclass:: TrickyDefector
.. autoclass:: Tullock
.. autoclass:: TwoTitsForTat
.. autoclass:: WinStayLoseShift
.. autoclass:: ZDExtort2
.. autoclass:: ZDGTFT2

Cheating strategies
-------------------

.. autoclass:: Darwin
.. autoclass:: Geller
.. autoclass:: GellerCooperator
.. autoclass:: GellerDefector
.. autoclass:: MindBender
.. autoclass:: MindController
.. autoclass:: MindReader
.. autoclass:: MindWarper
.. autoclass:: ProtectedMindReader
